@@ -1,22 +1,10 @@
-/***************************************************************************
-                              ExerciseConvert.cpp
-                             -------------------
-    begin                : 2004/06/04
-    copyright            : (C) 2004 by Sebastian Stein
-    email                : seb.kde@hpfsc.de
+/*
+    SPDX-FileCopyrightText: 2004 Sebastian Stein <seb.kde@hpfsc.de>
+    SPDX-FileCopyrightText: 2008 Tadeu Araujo <tadeu.araujo@ltia.fc.unesp.br>
+    SPDX-FileCopyrightText: 2008 Danilo Balzaque <danilo.balzaque@ltia.fc.unesp.br>
 
-    copyright            : (C) 2008 by Tadeu Araujo, tadeu.araujo@ltia.fc.unesp.br
-    copyright            : (C) 2008 by Danilo Balzaque, danilo.balzaque@ltia.fc.unesp.br
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "ExerciseConvert.h"
 
